@@ -14,9 +14,9 @@
 
 from oslo.config import cfg
 
+from murano.common.i18n import _
 from murano.common import wsgi
 import murano.context
-from murano.openstack.common.gettextutils import _  # noqa
 import murano.openstack.common.log as logging
 
 context_opts = [
