@@ -13,17 +13,16 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import types
+
 
 class TokenSanitizer(object):
-    """Helper class for cleaning some object from different passwords/tokens
-
+    """Helper class for cleaning some object from different passwords/tokens.
     Simply searches attribute with `look a like` name as one of
     the token and replace it value with message.
     """
-    def __init__(self, tokens=('token', 'pass', 'trustid'),
-                 message='*** SANITIZED ***'):
-        """Init method of TokenSanitizer
-
+    def __init__(self, tokens=('token', 'pass'), message='*** SANITIZED ***'):
+        """Init method of TokenSanitizer.
         :param tokens:  iterable with tokens
         :param message: string by which each token going to be replaced
         """
@@ -48,17 +47,16 @@ class TokenSanitizer(object):
 
     def sanitize(self, obj):
         """Replaces each token found in object by message.
-
-        :param obj: dict, list, tuple, object
+        :param obj: types.DictType, types.ListType, types.Tuple, object
         :return: Sanitized object
         """
-        if isinstance(obj, dict):
-            return dict([self.sanitize(item) for item in obj.items()])
-        elif isinstance(obj, list):
+        if isinstance(obj, types.DictType):
+            return dict([self.sanitize(item) for item in obj.iteritems()])
+        elif isinstance(obj, types.ListType):
             return [self.sanitize(item) for item in obj]
-        elif isinstance(obj, tuple):
+        elif isinstance(obj, types.TupleType):
             k, v = obj
-            if self._contains_token(k) and isinstance(v, str):
+            if self._contains_token(k) and isinstance(v, types.StringTypes):
                 return k, self.message
             return k, self.sanitize(v)
         else:
