@@ -13,12 +13,12 @@
 #    under the License.
 
 from oslo.db import exception
+from oslo.utils import timeutils
 import sqlalchemy
 from sqlalchemy.sql import func
 
 from murano.db import models
 from murano.db import session as db_session
-from murano.openstack.common import timeutils
 
 
 UNCLASSIFIED = 0
