@@ -15,12 +15,13 @@
 
 import copy
 import datetime
+import logging
 import os
 import types
+import urlparse
 import uuid
 
 import eventlet.event
-import logging
 
 import murano.common.config as config
 import murano.common.exceptions as exceptions
@@ -79,7 +80,13 @@ class Agent(murano_object.MuranoObject):
                 'Use of murano-agent is disallowed '
                 'by the server configuration')
 
-    def _send(self, template, wait_results, _context, timeout):
+    def _prepare_message(self, template, msg_id):
+        msg = messaging.Message()
+        msg.body = template
+        msg.id = msg_id
+        return msg
+
+    def _send(self, template, wait_results, timeout, _context):
         """Send a message over the MQ interface."""
         msg_id = template.get('ID', uuid.uuid4().hex)
         if wait_results:
@@ -87,10 +94,7 @@ class Agent(murano_object.MuranoObject):
             listener = self._environment.agentListener
             listener.subscribe(msg_id, event, _context)
 
-        msg = messaging.Message()
-        msg.body = template
-        msg.id = msg_id
-
+        msg = self._prepare_message(template, msg_id)
         with common.create_rmq_client() as client:
             client.send(message=msg, key=self._queue)
 
@@ -120,33 +124,33 @@ class Agent(murano_object.MuranoObject):
     def call(self, template, resources, _context, timeout=600):
         self._check_enabled()
         plan = self.buildExecutionPlan(template, resources)
-        return self._send(plan, True, _context, timeout)
+        return self._send(plan, True, timeout, _context)
 
     def send(self, template, resources, _context):
         self._check_enabled()
         plan = self.buildExecutionPlan(template, resources)
-        return self._send(plan, False, _context)
+        return self._send(plan, False, 0, _context)
 
-    def callRaw(self, plan, _context):
+    def callRaw(self, plan, _context, timeout=600):
         self._check_enabled()
-        return self._send(plan, True, _context)
+        return self._send(plan, True, timeout, _context)
 
     def sendRaw(self, plan, _context):
         self._check_enabled()
-        return self._send(plan, False, _context)
+        return self._send(plan, False, 0, _context)
 
-    def isReady(self, timeout=100):
+    def isReady(self, _context, timeout=100):
         try:
-            self.waitReady(timeout)
+            self.waitReady(_context, timeout)
         except exceptions.TimeoutException:
             return False
         else:
             return True
 
-    def waitReady(self, timeout=100):
+    def waitReady(self, _context, timeout=100):
         self._check_enabled()
         template = {'Body': 'return', 'FormatVersion': '2.0.0', 'Scripts': {}}
-        self.call(template, False, timeout)
+        self.call(template, False, _context, timeout)
 
     def _process_v1_result(self, result):
         if result['IsException']:
@@ -227,38 +231,103 @@ class Agent(murano_object.MuranoObject):
         files = {}
         for file_id, file_descr in template['Files'].items():
             files[file_descr['Name']] = file_id
+
         for name, script in template.get('Scripts', {}).items():
             if 'EntryPoint' not in script:
                 raise ValueError('No entry point in script ' + name)
-            script['EntryPoint'] = self._place_file(
-                scripts_folder, script['EntryPoint'],
-                template, files, resources)
-            if 'Files' in script:
-                for i in range(0, len(script['Files'])):
-                    script['Files'][i] = self._place_file(
-                        scripts_folder, script['Files'][i],
-                        template, files, resources)
 
+            if 'Application' in script['Type']:
+                script['EntryPoint'] = self._place_file(scripts_folder,
+                                                        script['EntryPoint'],
+                                                        template, resources,
+                                                        files)
+            if 'Files' in script:
+                for i, file in enumerate(script['Files']):
+                    script['Files'][i] = self._place_file(scripts_folder,
+                                                          file, template,
+                                                          resources,
+                                                          files)
         return template
 
-    def _place_file(self, folder, name, template, files, resources):
-        use_base64 = False
-        if name.startswith('<') and name.endswith('>'):
-            use_base64 = True
-            name = name[1:len(name) - 1]
-        if name in files:
-            return files[name]
+    def _is_url(self, file):
+        file = self._get_url(file)
+        parts = urlparse.urlsplit(file)
+        if not parts.scheme or not parts.netloc:
+            return False
+        else:
+            return True
 
-        file_id = uuid.uuid4().hex
-        body_type = 'Base64' if use_base64 else 'Text'
-        body = resources.string(os.path.join(folder, name))
+    def _get_url(self, file):
+        if isinstance(file, dict):
+            return file.values()[0]
+        else:
+            return file
+
+    def _get_name(self, file):
+        if isinstance(file, dict):
+            name = file.keys()[0]
+        else:
+            name = file
+
+        if self._is_url(name):
+            name = name[name.rindex('/') + 1:len(name)]
+        elif name.startswith('<') and name.endswith('>'):
+            name = name[1: -1]
+        return name
+
+    def _get_file_value(self, file):
+        if isinstance(file, dict):
+            file = file.values()[0]
+        return file
+
+    def _get_body(self, file, resources, folder):
+        use_base64 = self._is_base64(file)
+        if use_base64 and file.startswith('<') and file.endswith('>'):
+            file = file[1: -1]
+        body = resources.string(os.path.join(folder, file))
         if use_base64:
             body = body.encode('base64')
+        return body
 
-        template['Files'][file_id] = {
+    def _is_base64(self, file):
+        return file.startswith('<') and file.endswith('>')
+
+    def _get_body_type(self, file):
+        return 'Base64' if self._is_base64(file) else 'Text'
+
+    def _place_file(self, folder, file, template, resources, files):
+        file_value = self._get_file_value(file)
+        name = self._get_name(file)
+        file_id = uuid.uuid4().hex
+
+        if self._is_url(file_value):
+            template['Files'][file_id] = self._get_file_des_downloadable(file)
+            files[name] = file_id
+
+        else:
+            template['Files'][file_id] = self._get_file_description(file,
+                                                                    resources,
+                                                                    folder)
+            files[name] = file_id
+        return file_id
+
+    def _get_file_des_downloadable(self, file):
+        name = self._get_name(file)
+        file = self._get_file_value(file)
+        return {
+            'Name': str(name),
+            'URL': file,
+            'Type': 'Downloadable'
+        }
+
+    def _get_file_description(self, file, resources, folder):
+        name = self._get_name(file)
+        file_value = self._get_file_value(file)
+
+        body_type = self._get_body_type(file_value)
+        body = self._get_body(file_value, resources, folder)
+        return {
             'Name': name,
             'BodyType': body_type,
             'Body': body
         }
-        files[name] = file_id
-        return file_id
